==> falak-0.1.54.tgz: package/README.md <==
# Falak JS
> Falak Js Framework, A framework for lazy people.


# Why Falak
Well, there are many outstanding frameworks such as `Angular`, `React` or `Vue` that can be used to develop a web application.

But why falak? let's see what makes it different from other frameworks.

- Can develop more than application in one workspace, for example the website and the admin panel.
- Almost everything is automated here `javascript`, `sass` and `html` files, you don't have to **require** or **import** any javascript files to use it over and over.
- No need to duplicate assets like `logos`, images, icons or even style codes between all applications that you'll develop for one website, there is a `common` application to communicate between all applications and share any **common** data/files.
- Supporting multi languages by default **Localization**. 
- Supporting both style directions by default so you won't have to worry about writing two designs one for `LTR` and another for `RTL` version.  
- Easy to understand, and use.
- The development server is a lightweight one.
- Production doesn't take much time and can compile one or all applications in same time.
- Generating `.htaccess` files for Apache servers thus you won't have to look for one by yourself.  
- Too many packages that help you in your development.
- No complicated relations between components.

# Table Of Contents
- [Requirements](#requirements)
- [Installation](#installation)
- [Getting started](#getting-started)
- [Documentation](#documentation)

# Requirements
- You need to have nodejs `>= 8` installed in your machine.

# Installation
Just run the following command in your cli.
`npm install -g falak`

# Getting started
After a successful installation of the framework, let's try to use it.

First of, let's create new project

`flk new blog`

After it is done now we've two applications installed for the blog, the **blog application** and the **admin blog application**.

Now enter to the `blog` directory and let's give it a shot.

Run `flk serve ` to start the serve or `flk serve -o` to start the serve and open the application in the browser.

# Documentation

For full documentation check our [wiki docs](https://github.com/hassanzohdy/falak/wiki).

==> falak-0.1.74.tgz: package/README.md <==
# Falak JS
> Falak Js Framework, A mass quick production framework for lazy people.


# Why Falak
Well, there are many outstanding frameworks such as `Angular`, `React` or `Vue` that can be used to develop a web application.

But why falak? let's see what makes it different from other frameworks.

- Can develop more than application in one workspace, for example the website and the admin panel.
- Almost everything is automated here `javascript`, `sass` and `html` files, you don't have to **require** or **import** any javascript files to use it over and over.
- No need to duplicate assets like `logos`, images, icons or even style codes between all applications that you'll develop for one website, there is a `common` application to communicate between all applications and share any **common** data/files.
- Supporting multi languages by default **Localization**. 
- Supporting both style directions by default so you won't have to worry about writing two designs one for `LTR` and another for `RTL` version.  
- Easy to understand, and use.
- The development server is a lightweight one.
- Production doesn't take much time and can compile one or all applications in same time.
- Generating `.htaccess` files for Apache servers thus you won't have to look for one by yourself.  
- Packages everywhere to help you produce web apps quicker.
- No complicated relations between components.

# Table Of Contents
- [Falak JS](#Falak-JS)
- [Why Falak](#Why-Falak)
- [Table Of Contents](#Table-Of-Contents)
- [Requirements](#Requirements)
- [Installation](#Installation)
- [Getting started](#Getting-started)
- [Documentation](#Documentation)

# Requirements
- You need to have nodejs `>= 8` installed in your machine.

# Installation
Just run the following command in your cli.
`npm install -g falak`

# Getting started
After a successful installation of the framework, let's try to use it.

First of, let's create new project

`flk new blog`

After it is done now we've two applications installed for the blog, the **blog application** and the **admin blog application**.

Now enter to the `blog` directory and let's give it a shot.

Run `flk serve ` to start the serve or `flk serve -o` to start the serve and open the application in the browser.

# Documentation

For full documentation check our [wiki docs](https://github.com/hassanzohdy/falak/wiki).
